@@ -24,18 +24,15 @@ def main():
         type=int,
         default=DEFAULT_CACHE_SIZE,
         metavar=DEFAULT_CACHE_SIZE,
-        help='how many items to cache'
+        help='how many items to cache (0 is unlimited)'
     )
 
-    try:
-        maxsize = parser.parse_args().maxsize
-    except:
-        maxsize = DEFAULT_CACHE_SIZE
-
     try:
         set(
             map(
-                lru_cache(maxsize)(sys.stdout.write),
+                lru_cache(
+                    maxsize=None if parser.parse_args().maxsize == 0 else parser.parse_args().maxsize
+                )(sys.stdout.write),
                 sys.stdin
             )
         )
